require_relative "player"
require_relative "die"
require_relative "game_turn"
require_relative "treasure_trove"

module StudioGame
    class Game
    
        def initialize(name)
            @name = name.capitalize
            @players = []
        end
    
        def add_players(players)
            @players.push(players)
        end
        
        def load_players(from_file)
            File.readlines(from_file).each do |line|
                name,health = line.split(',')
                player = Player.new(name,Integer(health))
                add_players(player)
            end
        end
        
        def save_high_score(to_file = "high_scores.txt")
            File.open(to_file, "w") do |file|
                puts "Saving high score to file to #{to_file}"
                file.puts "#{@name} High Scores: "
                @players.each do |player|
                    formatted_name = player.name.ljust(20,'.')
                    file.puts "#{formatted_name} #{player.score}" 
                end
            end
        end
        
        def play(rounds)
            treasures = TreasureTrove::TREASURES
            puts  "There are #{treasures.size} treasures to be found:"
            treasures.each do |treasure|
                puts "Treasure: #{treasure.name}\t Points: #{treasure.points}"
            end
           1.upto(rounds) do |round|
                puts "\n"
                puts "Round: #{round}"
                @players.each do |player|
                    GameTurn.take_turn(player)
                end
            end
        end
        
        def print_name_and_health(player)
            puts "Player: #{player.name}\t Health:#{player.health}"
        end
        
        def print_stats
        
            strong_players, weak_players = @players.partition {|p| p.strong?}
            #weak_players = @players.reject {|p| p.strong?}
            
            puts "\n"
            puts "Strong Players:"
            strong_players.each do |player|
                print_name_and_health(player)
            end
            
            
            puts "\n"
            puts "Weak Players"
            weak_players.each do |player|
                print_name_and_health(player)
            end
            
            sorted_players = @players.sort
            
            puts "Knuckleheads High Score:"
            sorted_players.each do |player|
                puts "#{player.name}....................#{player.score} "
            end
            
            puts "\n"
            
            @players.each do |player|
                
                player.each_treasure do |treasure|
                    puts "#{treasure.points} total #{treasure.name} points"
                end
                
                puts "#{player.name}'s grand total points: #{player.points}"
                puts "\n"
                
            end
            
        end
    end
end